<?php 
/**
 * Plugin Name: Custom Translations (Matomo Plugin)
 * Plugin URI: http://plugins.matomo.org/CustomTranslations
 * Description: Translate entities and tracked values into different languages. For example Custom dimensions, dashboard names, custom report names, event values, ...
 * Author: InnoCraft
 * Author URI: https://innocraft.com
 * Version: 5.0.0
 */
?><?php
/**
 * InnoCraft - the company of the makers of Matomo Analytics, the free/libre analytics platform
 *
 * @link https://www.innocraft.com
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 */

namespace Piwik\Plugins\CustomTranslations;

use Piwik\API\Request;
use Piwik\Container\StaticContainer;
use Piwik\Piwik;
use Piwik\Plugins\CustomTranslations\TranslationTypes\TranslationTypeProvider;
use Piwik\SettingsServer;

 
if (defined( 'ABSPATH')
&& function_exists('add_action')) {
    $path = '/matomo/app/core/Plugin.php';
    if (defined('WP_PLUGIN_DIR') && WP_PLUGIN_DIR && file_exists(WP_PLUGIN_DIR . $path)) {
        require_once WP_PLUGIN_DIR . $path;
    } elseif (defined('WPMU_PLUGIN_DIR') && WPMU_PLUGIN_DIR && file_exists(WPMU_PLUGIN_DIR . $path)) {
        require_once WPMU_PLUGIN_DIR . $path;
    } else {
        return;
    }
    add_action('plugins_loaded', function () {
        if (function_exists('matomo_add_plugin')) {
            matomo_add_plugin(__DIR__, __FILE__, true);
        }
    });
}

class CustomTranslations extends \Piwik\Plugin
{
    public function registerEvents()
    {
        return array(
            'API.Request.dispatch.end' => 'updateEvents',
            'AssetManager.getStylesheetFiles' => 'getStylesheetFiles',
            'Translate.getClientSideTranslationKeys' => 'getClientSideTranslationKeys',
        );
    }

    public function getClientSideTranslationKeys(&$result)
    {
        $result[] = 'General_Language';
        $result[] = 'General_Value';
        $result[] = 'General_GoTo2';
        $result[] = 'CustomTranslations_Translation';
        $result[] = 'CustomTranslations_LanguageInlineHelp';
        $result[] = 'CustomTranslations_CustomTranslations';
    }

    public function getStylesheetFiles(&$stylesheets)
    {
        $stylesheets[] = "plugins/CustomTranslations/vue/src/EditCustomTranslations/EditCustomTranslations.less";
    }

    public function isTrackerPlugin()
    {
        return false;
    }

    public function updateEvents(&$returnedValue, $extraInfo)
    {
        if (empty($extraInfo['module']) || empty($extraInfo['action'])) {
            return;
        }

        if (SettingsServer::isTrackerApiRequest()) {
            return;
        }

        if (SettingsServer::isArchivePhpTriggered()) {
            return;
        }

        if (!Piwik::isUserHasSomeViewAccess()) {
            return;
        }

        if (Request::getRootApiRequestMethod() === 'API.getSuggestedValuesForSegment') {
            // we need to make sure to return the raw words here
            return;
        }

        $module = $extraInfo['module'];
        $action = $extraInfo['action'];
        $method = $module . '.' . $action;

        $provider = StaticContainer::get(TranslationTypeProvider::class);

        foreach ($provider->getAllTranslationTypes() as $type) {
            $returnedValue = $type->translate($returnedValue, $method, $extraInfo);
        }
    }

}
